@@ -1,6 +1,8 @@
-import click
-from pipes import quote
 import io
+from pipes import quote
+import click
+
+from convisoappsec.flow.util.ci_provider import CIProvider
 
 
 class DeployFormatter(object):
@@ -64,7 +66,7 @@ class DeployFormatter(object):
         buffer = io.StringIO()
 
         for var_name, var_val in env_vars.items():
-            line_fmt = "{name}={value}"
+            line_fmt = "export {name}={value}"
             line = line_fmt.format(
               name=quote(var_name),
               value=quote(var_val),
@@ -119,3 +121,24 @@ def project_code_option(*args, **kargs):
         *paramsdecl,
         **kargs,
     )
+    
+
+def __try_retrieve_ci_provider(provider_name):
+    try:
+        return CIProvider[provider_name]
+    except KeyError as e:
+        error_msg_fmt = 'Received for parameter provider_name[{}]. Expected values are: [{}]'
+        expected_values = '|'.join(CIProvider.names())
+        error_msg = error_msg_fmt.format(provider_name, expected_values)
+
+        raise ValueError(error_msg) from e
+
+def process_ci_provider_option(provider_name, env={}):
+    if provider_name is not None:
+        return __try_retrieve_ci_provider(provider_name)
+
+    for provider in CIProvider:
+        if provider.env_vars_exists(env):
+            return provider
+
+    return CIProvider.OTHER
\ No newline at end of file
