@@ -41,20 +41,44 @@ def time_(
         previous_version = result.previous_version
         diff_content = None
 
+        current_commit = current_version.get('commit')
+        previous_commit = previous_version.get('commit')
+
+        if previous_commit == current_commit:
+            import sys
+            click.echo(
+                "Previous commit ({0}) and Current commit ({1}) are the same, nothing to do.".format(
+                    previous_commit, current_commit
+                ),
+                file=sys.stderr
+            )
+            return
+
         if attach_diff:
             diff_content = git_adapter.diff(
-                    previous_version.get('commit'),
-                    current_version.get('commit'),
+                previous_commit,
+                current_commit,
             )
 
+        deploy_metrics = git_adapter.diff_stats(
+            previous_commit,
+            current_commit,
+        ).dict
+
         flow = flow_context.create_flow_api_client()
 
+        authors_data = git_adapter.get_commit_authors_by_range(
+            previous_commit, current_commit
+        )
+
         deploy = flow.deploys.create(
             project_code,
             current_version=current_version,
             previous_version=previous_version,
             diff_content=diff_content,
-            project_metrics=project_metrics(repository_dir)
+            metrics=deploy_metrics,
+            project_metrics=project_metrics(repository_dir),
+            commit_authors=authors_data
         )
 
         click.echo(
