@@ -55,6 +55,10 @@ def values(
             try:
                 latest_deploy = flow.deploys.get_latest(project_code)
                 previous_commit = latest_deploy.get('current_commit')
+
+                if not previous_commit:
+                    previous_tag = latest_deploy.get('current_tag')
+                    previous_commit = git_adapter.show_commit_from_tag(previous_tag)
             except api.DeployNotFoundException:
                 previous_commit = git_adapter.empty_repository_tree_commit
 
@@ -66,8 +70,13 @@ def values(
                 ),
                 file=sys.stderr
             )
+
+            click.echo(
+                create_context.output_formatter.format(latest_deploy)
+            )
+
             return
-            
+
         diff_content = None
 
         if attach_diff:
@@ -81,13 +90,18 @@ def values(
             current_commit,
         ).dict
 
+        authors_data = git_adapter.get_commit_authors_by_range(
+            previous_commit, current_commit
+        )
+
         deploy = flow.deploys.create(
             project_code,
             current_version={'commit': current_commit},
             previous_version={'commit': previous_commit},
             diff_content=diff_content,
             metrics=deploy_metrics,
-            project_metrics=project_metrics(repository_dir)
+            project_metrics=project_metrics(repository_dir),
+            commit_authors=authors_data
         )
 
         click.echo(
